@@ -28,7 +28,7 @@ from typing import NamedTuple, List, Tuple
 # from black import format_str, FileMode
 
 HOME_PATH = Path("compiler/api")
-DESTINATION_PATH = Path("geezlibs/raw")
+DESTINATION_PATH = Path("ubotlibs/raw")
 NOTICE_PATH = "NOTICE"
 
 SECTION_RE = re.compile(r"---(\w+)---")
@@ -176,13 +176,13 @@ def get_docstring_arg_type(t: str):
         else:
             return f"``{t.lower()}``"
     elif t == "TLObject" or t == "X":
-        return "Any object from :obj:`~geezlibs.raw.types`"
+        return "Any object from :obj:`~ubotlibs.raw.types`"
     elif t == "!X":
-        return "Any function from :obj:`~geezlibs.raw.functions`"
+        return "Any function from :obj:`~ubotlibs.raw.functions`"
     elif t.lower().startswith("vector"):
         return "List of " + get_docstring_arg_type(t.split("<", 1)[1][:-1])
     else:
-        return f":obj:`{t} <geezlibs.raw.base.{t}>`"
+        return f":obj:`{t} <ubotlibs.raw.base.{t}>`"
 
 
 def get_references(t: str, kind: str):
@@ -336,7 +336,7 @@ def start(format: bool = False):
 
         docstring += f"\n\n    Constructors:\n" \
                      f"        This base type has {constr_count} constructor{'s' if constr_count > 1 else ''} available.\n\n" \
-                     f"        .. currentmodule:: geezlibs.raw.types\n\n" \
+                     f"        .. currentmodule:: ubotlibs.raw.types\n\n" \
                      f"        .. autosummary::\n" \
                      f"            :nosignatures:\n\n" \
                      f"            {items}"
@@ -346,7 +346,7 @@ def start(format: bool = False):
         if references:
             docstring += f"\n\n    Functions:\n        This object can be returned by " \
                          f"{ref_count} function{'s' if ref_count > 1 else ''}.\n\n" \
-                         f"        .. currentmodule:: geezlibs.raw.functions\n\n" \
+                         f"        .. currentmodule:: ubotlibs.raw.functions\n\n" \
                          f"        .. autosummary::\n" \
                          f"            :nosignatures:\n\n" \
                          f"            " + references
@@ -419,7 +419,7 @@ def start(format: bool = False):
                 constructor_docs = "Telegram API type."
 
             docstring += constructor_docs + "\n"
-            docstring += f"\n    Constructor of :obj:`~geezlibs.raw.base.{c.qualtype}`."
+            docstring += f"\n    Constructor of :obj:`~ubotlibs.raw.base.{c.qualtype}`."
         else:
             function_docs = docs["method"].get(c.qualname, None)
 
@@ -440,7 +440,7 @@ def start(format: bool = False):
             if references:
                 docstring += f"\n    Functions:\n        This object can be returned by " \
                              f"{count} function{'s' if count > 1 else ''}.\n\n" \
-                             f"        .. currentmodule:: geezlibs.raw.functions\n\n" \
+                             f"        .. currentmodule:: ubotlibs.raw.functions\n\n" \
                              f"        .. autosummary::\n" \
                              f"            :nosignatures:\n\n" \
                              f"            " + references
@@ -630,23 +630,23 @@ def start(format: bool = False):
         f.write("objects = {")
 
         for c in combinators:
-            f.write(f'\n    {c.id}: "geezlibs.raw.{c.section}.{c.qualname}",')
+            f.write(f'\n    {c.id}: "ubotlibs.raw.{c.section}.{c.qualname}",')
 
-        f.write('\n    0xbc799737: "geezlibs.raw.core.BoolFalse",')
-        f.write('\n    0x997275b5: "geezlibs.raw.core.BoolTrue",')
-        f.write('\n    0x1cb5c415: "geezlibs.raw.core.Vector",')
-        f.write('\n    0x73f1f8dc: "geezlibs.raw.core.MsgContainer",')
-        f.write('\n    0xae500895: "geezlibs.raw.core.FutureSalts",')
-        f.write('\n    0x0949d9dc: "geezlibs.raw.core.FutureSalt",')
-        f.write('\n    0x3072cfa1: "geezlibs.raw.core.GzipPacked",')
-        f.write('\n    0x5bb8e511: "geezlibs.raw.core.Message",')
+        f.write('\n    0xbc799737: "ubotlibs.raw.core.BoolFalse",')
+        f.write('\n    0x997275b5: "ubotlibs.raw.core.BoolTrue",')
+        f.write('\n    0x1cb5c415: "ubotlibs.raw.core.Vector",')
+        f.write('\n    0x73f1f8dc: "ubotlibs.raw.core.MsgContainer",')
+        f.write('\n    0xae500895: "ubotlibs.raw.core.FutureSalts",')
+        f.write('\n    0x0949d9dc: "ubotlibs.raw.core.FutureSalt",')
+        f.write('\n    0x3072cfa1: "ubotlibs.raw.core.GzipPacked",')
+        f.write('\n    0x5bb8e511: "ubotlibs.raw.core.Message",')
 
         f.write("\n}\n")
 
 
 if "__main__" == __name__:
     HOME_PATH = Path(".")
-    DESTINATION_PATH = Path("../../geezlibs/raw")
+    DESTINATION_PATH = Path("../../ubotlibs/raw")
     NOTICE_PATH = Path("../../NOTICE")
 
     start(format=False)
