@@ -18,7 +18,7 @@
 
 import pytest
 
-from geezlibs.file_id import FileId, FileUniqueId, FileType, FileUniqueType
+from ubotlibs.file_id import FileId, FileUniqueId, FileType, FileUniqueType
 
 
 def check(file_id: str, expected_file_type: FileType):
