@@ -33,24 +33,24 @@ from mimetypes import MimeTypes
 from pathlib import Path
 from typing import Union, List, Optional, Callable, AsyncGenerator
 
-import geezlibs
-from geezlibs import __version__, __license__
-from geezlibs import enums
-from geezlibs import raw
-from geezlibs import utils
-from geezlibs.crypto import aes
-from geezlibs.errors import CDNFileHashMismatch
-from geezlibs.errors import (
+import ubotlibs
+from ubotlibs import __version__, __license__
+from ubotlibs import enums
+from ubotlibs import raw
+from ubotlibs import utils
+from ubotlibs.crypto import aes
+from ubotlibs.errors import CDNFileHashMismatch
+from ubotlibs.errors import (
     SessionPasswordNeeded,
     VolumeLocNotFound, ChannelPrivate,
     AuthBytesInvalid, BadRequest, ListenerCanceled
 )
-from geezlibs.handlers.handler import Handler
-from geezlibs.methods import Methods
-from geezlibs.session import Auth, Session
-from geezlibs.storage import FileStorage, MemoryStorage
-from geezlibs.types import User, TermsOfService
-from geezlibs.utils import ginput
+from ubotlibs.handlers.handler import Handler
+from ubotlibs.methods import Methods
+from ubotlibs.session import Auth, Session
+from ubotlibs.storage import FileStorage, MemoryStorage
+from ubotlibs.types import User, TermsOfService
+from ubotlibs.utils import ginput
 from .dispatcher import Dispatcher
 from .file_id import FileId, FileType, ThumbnailSource
 from .mime_types import mime_types
@@ -116,7 +116,7 @@ class Client(Methods):
         in_memory (``bool``, *optional*):
             Pass True to start an in-memory session that will be discarded as soon as the client stops.
             In order to reconnect again using an in-memory session without having to login again, you can use
-            :meth:`~geezlibs.Client.export_session_string` before stopping the client to get a session string you can
+            :meth:`~ubotlibs.Client.export_session_string` before stopping the client to get a session string you can
             pass to the ``session_string`` parameter.
             Defaults to False.
 
@@ -144,7 +144,7 @@ class Client(Methods):
         plugins (``dict``, *optional*):
             Smart Plugins settings as dict, e.g.: *dict(root="plugins")*.
 
-        parse_mode (:obj:`~geezlibs.enums.ParseMode`, *optional*):
+        parse_mode (:obj:`~ubotlibs.enums.ParseMode`, *optional*):
             Set the global parse mode of the client. By default, texts are parsed using both Markdown and HTML styles.
             You can combine both syntaxes together.
 
@@ -450,14 +450,14 @@ class Client(Methods):
         global value by default.
 
         Parameters:
-            parse_mode (:obj:`~geezlibs.enums.ParseMode`):
+            parse_mode (:obj:`~ubotlibs.enums.ParseMode`):
                 By default, texts are parsed using both Markdown and HTML styles.
                 You can combine both syntaxes together.
 
         Example:
             .. code-block:: python
 
-                from geezlibs import enums
+                from ubotlibs import enums
 
                 # Default combined mode: Markdown + HTML
                 await app.send_message("me", "1. **markdown** and <i>html</i>")
@@ -1011,7 +1011,7 @@ class Client(Methods):
                             break
                 except Exception as e:
                     raise e
-        except geezlibs.StopTransmission:
+        except ubotlibs.StopTransmission:
             raise
         except Exception as e:
             log.error(e, exc_info=True)
