@@ -16,12 +16,12 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from darmilibs import raw
+from geezlibs import raw
 from .auto_name import AutoName
 
 
 class NextCodeType(AutoName):
-    """Next code type enumeration used in :obj:`~darmilibs.types.SentCode`."""
+    """Next code type enumeration used in :obj:`~geezlibs.types.SentCode`."""
 
     CALL = raw.types.auth.CodeTypeCall
     "The code will be sent via a phone call. A synthesized voice will tell the user which verification code to input."
