@@ -22,7 +22,7 @@ from .auto_name import AutoName
 
 
 class PollType(AutoName):
-    """Poll type enumeration used in :obj:`~darmilibs.types.Poll`."""
+    """Poll type enumeration used in :obj:`~geezlibs.types.Poll`."""
 
     QUIZ = auto()
     "Quiz poll"
