@@ -18,15 +18,15 @@
 
 import logging
 
-import darmilibs
-from darmilibs import raw
+import geezlibs
+from geezlibs import raw
 
 log = logging.getLogger(__name__)
 
 
 class GetPasswordHint:
     async def get_password_hint(
-        self: "darmilibs.Client",
+        self: "geezlibs.Client",
     ) -> str:
         """Get your Two-Step Verification password hint.
 
