@@ -1,6 +1,6 @@
 from sqlalchemy import Boolean, Column, String, UnicodeText
 
-from darmilibs.ram.helpers.SQL import BASE, SESSION
+from geezlibs.ram.helpers.SQL import BASE, SESSION
 
 Owner = 0
 
