@@ -1,4 +1,4 @@
-from darmilibs.ram.helpers.SQL import BASE, SESSION
+from geezlibs.ram.helpers.SQL import BASE, SESSION
 from pyrogram import Client
 from sqlalchemy import Column, String, UnicodeText
 
