@@ -1,7 +1,7 @@
 from sqlalchemy import Column, Numeric
 
 try:
-    from darmilibs.ram.helpers.SQL import BASE, SESSION
+    from geezlibs.ram.helpers.SQL import BASE, SESSION
 except ImportError:
     raise AttributeError
 
