@@ -23,4 +23,4 @@ from .tl_object import TLObject
 
 class List(TList[Any], TLObject):
     def __repr__(self) -> str:
-        return f"darmilibs.raw.core.List([{','.join(TLObject.__repr__(i) for i in self)}])"
+        return f"geezlibs.raw.core.List([{','.join(TLObject.__repr__(i) for i in self)}])"
