@@ -16,9 +16,9 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from darmilibs.raw.core import Message, MsgContainer, TLObject
-from darmilibs.raw.functions import Ping
-from darmilibs.raw.types import MsgsAck, HttpWait
+from geezlibs.raw.core import Message, MsgContainer, TLObject
+from geezlibs.raw.functions import Ping
+from geezlibs.raw.types import MsgsAck, HttpWait
 from .msg_id import MsgId
 from .seq_no import SeqNo
 
