@@ -16,12 +16,12 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-import darmilibs
+import geezlibs
 
 
 class Update:
     def stop_propagation(self):
-        raise darmilibs.StopPropagation
+        raise geezlibs.StopPropagation
 
     def continue_propagation(self):
-        raise darmilibs.ContinuePropagation
+        raise geezlibs.ContinuePropagation
